AttentionEdgeWeighting
======================

.. currentmodule:: pykeen.nn.weighting

.. autoclass:: AttentionEdgeWeighting
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AttentionEdgeWeighting.needs_message

   .. rubric:: Methods Summary

   .. autosummary::

      ~AttentionEdgeWeighting.forward

   .. rubric:: Attributes Documentation

   .. autoattribute:: needs_message

   .. rubric:: Methods Documentation

   .. automethod:: forward
